# adutils

[![PyPI](https://img.shields.io/pypi/v/adutils)](https://pypi.org/project/adutils/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/adutils)](https://pypi.org/project/adutils/) [![PyPI - Downloads](https://img.shields.io/pypi/dm/adutils)](https://pypi.org/project/adutils/)

Helper functions for AppDaemon apps. Currently there is just code, no documentation. Sorry ¯\\_(ツ)_/¯

## Install

```bash
pip install adutils
```

## Apps using **adutils**

* [AutoMoLi](https://github.com/benleb/ad-automoli)
* [EnCh](https://github.com/benleb/ad-ench)
* [Notifreeze](https://github.com/benleb/ad-notifreeze)
* [Healthcheck](https://github.com/benleb/ad-healthcheck)
